FaIconData class final

A wrapper for IconData to ensure type safety and correct rendering with FaIcon.

This class prevents usage of Font Awesome icons in the standard Icon widget, which would result in incorrect rendering (clipping/misalignment) for non-square icons.

Annotations

Constructors

FaIconData(IconData data)
Creates a wrapper for the given data.
const

Properties

codePoint int
The code point of the icon.
no setter
data IconData
The underlying IconData for this font awesome icon.
final
fontFamily String?
The font family of the icon.
no setter
fontPackage String?
The font package of the icon.
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override